/*
 * Copyright (c) 2002-2017, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.gru.business.demandtype;

import fr.paris.lutece.portal.service.plugin.Plugin;
import fr.paris.lutece.util.ReferenceList;

import java.util.List;

/**
 * IDemandTypeDAO Interface
 */
public interface IDemandTypeDAO
{
    /**
     * Insert a new record in the table.
     * 
     * @param demandType
     *            instance of the DemandType object to insert
     * @param plugin
     *            the Plugin
     */
    void insert( DemandType demandType, Plugin plugin );

    /**
     * Update the record in the table
     * 
     * @param demandType
     *            the reference of the DemandType
     * @param plugin
     *            the Plugin
     */
    void store( DemandType demandType, Plugin plugin );

    /**
     * Delete a record from the table
     * 
     * @param nKey
     *            The identifier of the DemandType to delete
     * @param plugin
     *            the Plugin
     */
    void delete( int nKey, Plugin plugin );

    // /////////////////////////////////////////////////////////////////////////
    // Finders

    /**
     * Load the data from the table
     * 
     * @param nKey
     *            The identifier of the demandType
     * @param plugin
     *            the Plugin
     * @return The instance of the demandType
     */
    DemandType load( int nKey, Plugin plugin );

    /**
     * Load the data of all the demandType objects and returns them as a collection
     * 
     * @param plugin
     *            the Plugin
     * @return The collection which contains the data of all the demandType objects
     */
    List<DemandType> selectDemandTypesList( Plugin plugin );

    /**
     * Load the id of all the demandType objects and returns them as a collection
     * 
     * @param plugin
     *            the Plugin
     * @return The collection which contains the id of all the demandType objects
     */
    List<Integer> selectIdDemandTypesList( Plugin plugin );

    /**
     * Return a reference list of all demands
     * 
     * @param plugin
     *            The plugin
     * @return The list
     */
    ReferenceList selectDemandTypes( Plugin plugin );

    /**
     * Find a DemandType by its DemandTypeId
     * 
     * @param strDemandTypeId
     *            The demandTypeId
     * @param plugin
     *            The plugin
     * @return The DemandType
     */
    DemandType selectByTypeId( String strDemandTypeId, Plugin plugin );
}
